package betterquesting.network.handlers;

import betterquesting.api.api.QuestingAPI;
import betterquesting.api.events.DatabaseEvent;
import betterquesting.api.network.QuestingPacket;
import betterquesting.core.BetterQuesting;
import betterquesting.network.PacketSender;
import betterquesting.network.PacketTypeRegistry;
import betterquesting.questing.party.PartyInvitations;
import cpw.mods.fml.relauncher.Side;
import cpw.mods.fml.relauncher.SideOnly;
import java.util.Collections;
import java.util.UUID;
import javax.annotation.Nonnull;
import net.minecraft.client.Minecraft;
import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import net.minecraft.util.ResourceLocation;
import net.minecraftforge.common.MinecraftForge;

/* loaded from: betterquesting_network_handlers.jar:betterquesting/network/handlers/NetInviteSync.class */
public class NetInviteSync {
    private static final ResourceLocation ID_NAME = new ResourceLocation("betterquesting:invite_sync");

    public static void registerHandler() {
        if (BetterQuesting.proxy.isClient()) {
            PacketTypeRegistry.INSTANCE.registerClientHandler(ID_NAME, NetInviteSync::onClient);
        }
    }

    public static void sendSync(@Nonnull EntityPlayerMP player) {
        NBTTagCompound payload = new NBTTagCompound();
        UUID playerID = QuestingAPI.getQuestingUUID(player);
        payload.func_74768_a("action", 0);
        payload.func_74782_a("data", PartyInvitations.INSTANCE.writeToNBT(new NBTTagList(), Collections.singletonList(playerID)));
        PacketSender.INSTANCE.sendToPlayers(new QuestingPacket(ID_NAME, payload), new EntityPlayerMP[]{player});
    }

    public static void sendRevoked(@Nonnull EntityPlayerMP player, int... IDs) {
        NBTTagCompound payload = new NBTTagCompound();
        payload.func_74768_a("action", 1);
        payload.func_74783_a("IDs", IDs);
        PacketSender.INSTANCE.sendToPlayers(new QuestingPacket(ID_NAME, payload), new EntityPlayerMP[]{player});
    }

    @SideOnly(Side.CLIENT)
    private static void onClient(NBTTagCompound message) {
        int action = message.func_74762_e("action");
        if (action == 0) {
            PartyInvitations.INSTANCE.readFromNBT(message.func_150295_c("data", 10), true);
            MinecraftForge.EVENT_BUS.post(new DatabaseEvent.Update(DatabaseEvent.DBType.PARTY));
        } else if (action == 1) {
            UUID playerID = QuestingAPI.getQuestingUUID(Minecraft.func_71410_x().field_71439_g);
            PartyInvitations.INSTANCE.revokeInvites(playerID, message.func_74759_k("IDs"));
            MinecraftForge.EVENT_BUS.post(new DatabaseEvent.Update(DatabaseEvent.DBType.PARTY));
        }
    }
}
